@@ -11,9 +11,5 @@
 % the type of the variable, not the value.  So if, for example,
 % y is a float array containing all integer values, it will
 % still return a logical 0.
-
-% Copyright (c) 2002-2007 Samit Basu
-% Licensed under the GPL
-
 function x = isinttype(y)
-  x = any(strcmp({'uint8','int8','uint16','int16','uint32','int32','uint64','int64'},class(y)));
+  x = isinteger(y);
