@@ -14,4 +14,4 @@
 % Licensed under the GPL
 
 function x = isnumeric(y)
-  x = any(strcmp({'uint8','int8','uint16','int16','uint32','int32','uint64','int64','float','double','complex','dcomplex'},class(y)));
+  x = any(strcmp({'uint8','int8','uint16','int16','uint32','int32','uint64','int64','single','double'},class(y)));
