@@ -10,7 +10,8 @@
 % and a logical 0 otherwise.
 
 % Copyright (c) 2002-2006 Samit Basu
+% Licensed under the GPL
 
 function x = isstr(y)
-  x = isa(y,'string');
+  x = isa(y,'char');
 
