@@ -38,7 +38,7 @@ end
 cmap = get(gcf,'colormap'); N = size(cmap,1);
 cmap = linspace(0,N,N)';
 cmap = repmat(cmap,[1,4]);
-han = himage('ydata',get(axhan,'clim'),'cdata',flipud(cmap));
+han = himage('ydata',get(axhan,'clim'),'cdata',cmap);
 axis('tight');
 axes(axhan);
 
@@ -46,7 +46,7 @@ function cba = findColorBar(axhan)
 fig = get(axhan,'parent');
 peers = get(fig,'children');
 for i = 1:numel(peers)
-  if (ishandle(peers(i),'axes') & (strcmp(get(peers(i),'tag'),'colorbar')) & (get(peers(i),'userdata') == axhan))
+  if (ishandle(peers(i),'axes') && (strcmp(get(peers(i),'tag'),'colorbar')) && (get(peers(i),'userdata') == axhan))
     cba = peers(i);
     return;
   end
