@@ -19,11 +19,12 @@
 % 
 
 % Copyright (c) 2002-2006 Samit Basu
+% Licensed under the GPL
 
 function hout = plot3(varargin)
   % Check for an axes handle
   if (nargin>=2)
-    if (isnumeric(varargin{1}) & (length(varargin{1})==1) & ...
+    if (isnumeric(varargin{1}) && (length(varargin{1})==1) && ...
     ishandle(varargin{1},'axes'))
        handle = varargin{1}(1);
        varargin(1) = [];
@@ -38,14 +39,14 @@ function hout = plot3(varargin)
   propstart = 0;
   if (nargin > 2)
     propstart = nargin-1;
-    while ((propstart >= 1) & isa(varargin{propstart},'string') & ...
+    while ((propstart >= 1) && isa(varargin{propstart},'char') && ...
     pvalid('line',varargin{propstart}))
       propstart = propstart - 2;
     end
     propstart = propstart + 2;
   end
   propset = {};
-  if ((propstart > 0) & (propstart < nargin))
+  if ((propstart > 0) && (propstart < nargin))
      propset = varargin(propstart:end);
 	varargin(propstart:end) = [];
   end
@@ -55,14 +56,18 @@ function hout = plot3(varargin)
     if (length(varargin) < 3)
       error('plot3 requires triplets of x, y, z coordinates');
     end;
-    if (length(varargin) == 3 | (length(varargin) > 3) & ~islinespec(varargin{4},cs,ms,ps))
+    if (length(varargin) == 3 || (length(varargin) > 3) && ~islinespec(varargin{4},cs,ms,ps))
       h = [h,plot_triplet(varargin{1},varargin{2},varargin{3},handle,propset)];
       varargin(1:3) = [];
-    elseif ((length(varargin) >= 4) & islinespec(varargin{4},cs,ms,ps))
+    elseif ((length(varargin) >= 4) && islinespec(varargin{4},cs,ms,ps))
       h = [h,plot_triplet(varargin{1},varargin{2},varargin{3},handle,completeprops(cs,ms,ps,propset))];
       varargin(1:4) = [];
     end;
   end
+if ~ishold
+	view( handle, 3 );
+	grid;
+end
 axes(saveca);
 if (nargout > 0)
    hout = h;
@@ -70,7 +75,7 @@ end
     
 function h = plot_triplet(X,Y,Z,handle,lineprops)
     h = [];
-    if ((isvector(X) | isvector(Y) | isvector(Z)) & (~isvector(X) | ~isvector(Y) | ~isvector(Z)))
+    if ((isvector(X) | isvector(Y) | isvector(Z)) && (~isvector(X) | ~isvector(Y) | ~isvector(Z)))
       rows = max([size(X,1),size(Y,1),size(Z,1)]);
       cols = max([size(X,2),size(Y,2),size(Z,2)]);
       X = expandmat(X,rows,cols);
@@ -99,6 +104,6 @@ function k = tplotvector(handle,x,y,z,lineprops)
   % Get the colororder
   colororder = get(handle,'colororder');
   % select the row using a modulo
-  ndxmod = uint32(mod(ndx-1,size(colororder,1))+1);
+  ndxmod = round(mod(ndx-1,size(colororder,1))+1);
   k = hline('xdata',x,'ydata',y,'zdata',z,'color',colororder(ndxmod,:),lineprops{:});
 
