@@ -38,7 +38,7 @@
 
 function hout = subplot(varargin)
   m = 1; n = 1; p = 1;
-  if ((nargin == 2) && (isa(varargin{1},'string')))
+  if ((nargin == 2) && (isa(varargin{1},'char')))
     if (strcmp(lower(varargin{1}),'position'))
         h = axes('outerposition',varargin{2});
         if (nargout > 0), hout = h; end;
@@ -46,7 +46,7 @@ function hout = subplot(varargin)
     end
   end
   if (nargin == 1)
-    if (isa(varargin{1},'string'))
+    if (isa(varargin{1},'char'))
       str = varargin{1};
       if (length(str) ~= 3), error('Subplot with a string argument requires a string of the type mnp'); end
       m = str(1)-'0';
@@ -57,12 +57,12 @@ function hout = subplot(varargin)
       h = varargin{1}(1);
     end
   else
-    if (nargin >= 1), m = int32(varargin{1}(1)); end
-    if (nargin >= 2), n = int32(varargin{2}(1)); end
-    if (nargin >= 3), p = int32(varargin{3}); p = p(:); end
+      if (nargin >= 1), m = round(varargin{1}(1)); end
+      if (nargin >= 2), n = round(varargin{2}(1)); end
+      if (nargin >= 3), p = round(varargin{3}); p = p(:); end
   end
-  row = m+1-int32(idiv(p-1,n)+1);
-  col = int32(mod(p-1,n)+1);
+  row = m+1-round(idiv(p-1,n)+1);
+  col = round(mod(p-1,n)+1);
   width = 1.0/n;
   height = 1.0/m;
   left = (col-1)*width;
