@@ -13,7 +13,6 @@
 % Licensed under the GPL
 
 function y = acosd(x)
-  if (nargin == 0 || ~isnumeric(x) || ~isreal(x))
-    error('acosd expects a real numeric input');
-  end
   y = rad2deg(acos(x));
+  y(x == inf) = complex(0,inf);
+  y(x == -inf) = complex(180,-inf);
