@@ -9,13 +9,9 @@
 % 
 % where x is an n-dimensional array of numerical type.
 
-
 % Copyright (c) 2002-2007 Samit Basu
 % Licensed under the GPL
 
 function y = acsch(x)
-  if (nargin == 0 || ~isnumeric(x))
-    error('acsch expects a single, numeric input');
-  end
-  y = asinh(1.f./x);
+  y = asinh(1 ./ x);
   
