@@ -13,7 +13,5 @@
 % Licensed under the GPL
 
 function y = asecd(x)
-  if (nargin == 0 || ~isnumeric(x))
-    error('asecd expects a numeric input');
-  end
   y = rad2deg(asec(x));
+  y(x == 0) = complex(0,inf);
