@@ -15,9 +15,5 @@
 % Licensed under the GPL
 
 function y = deg2rad(x)
-  if (isa(x,'float') || isa(x,'complex'))
-    y = x*float(pi/180);
-  else
-    y = x*pi/180;
-  end
+  y = x*pi/180;
   
